hydra\_zen.wrapper.Zen
======================

.. currentmodule:: hydra_zen.wrapper

.. autoclass:: Zen

   
   .. automethod:: __init__
   .. automethod:: __call__
   .. automethod:: validate
   .. automethod:: hydra_main

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Zen.__init__
      ~Zen.__call__
      ~Zen.validate
      ~Zen.hydra_main
